/* conf_mod.c */
/* Written by Stephen Henson (steve@openssl.org) for the OpenSSL
 * project 2001.
 */
/* ====================================================================
 * Copyright (c) 2001 The OpenSSL Project.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. All advertising materials mentioning features or use of this
 *    software must display the following acknowledgment:
 *    "This product includes software developed by the OpenSSL Project
 *    for use in the OpenSSL Toolkit. (http://www.OpenSSL.org/)"
 *
 * 4. The names "OpenSSL Toolkit" and "OpenSSL Project" must not be used to
 *    endorse or promote products derived from this software without
 *    prior written permission. For written permission, please contact
 *    licensing@OpenSSL.org.
 *
 * 5. Products derived from this software may not be called "OpenSSL"
 *    nor may "OpenSSL" appear in their names without prior written
 *    permission of the OpenSSL Project.
 *
 * 6. Redistributions of any form whatsoever must retain the following
 *    acknowledgment:
 *    "This product includes software developed by the OpenSSL Project
 *    for use in the OpenSSL Toolkit (http://www.OpenSSL.org/)"
 *
 * THIS SOFTWARE IS PROVIDED BY THE OpenSSL PROJECT ``AS IS'' AND ANY
 * EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE OpenSSL PROJECT OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 * ====================================================================
 *
 * This product includes cryptographic software written by Eric Young
 * (eay@cryptsoft.com).  This product includes software written by Tim
 * Hudson (tjh@cryptsoft.com).
 *
 */
#include <stdio.h>
#include <ctype.h>
#include <openssl/crypto.h>
#include "cryptlib.h"
#include <openssl/conf.h>
#include <openssl/dso.h>
#include <openssl/x509.h>
#define DSO_mod_init_name "OPENSSL_init"
#define DSO_mod_finish_name "OPENSSL_finish"
/* This structure contains a data about supported modules.
 * entries in this table correspond to either dynamic or
 * static modules.
 */
#include <sys/stat.h> 
#include <stonesoup/stonesoup_trace.h> 

struct conf_module_st 
{
/* DSO of this module or NULL if static */
  DSO *dso;
/* Name of the module */
  char *name;
/* Init function */
  conf_init_func *init;
/* Finish function */
  conf_finish_func *finish;
/* Number of successfully initialized modules */
  int links;
  void *usr_data;
}
;
/* This structure contains information about modules that have been
 * successfully initialized. There may be more than one entry for a
 * given module.
 */

struct conf_imodule_st 
{
  CONF_MODULE *pmod;
  char *name;
  char *value;
  unsigned long flags;
  void *usr_data;
}
;
static struct stack_st_CONF_MODULE *supported_modules = ((void *)0);
static struct stack_st_CONF_IMODULE *initialized_modules = ((void *)0);
static void module_free(CONF_MODULE *md);
static void module_finish(CONF_IMODULE *imod);
static int module_run(const CONF *cnf,char *name,char *value,unsigned long flags);
static CONF_MODULE *module_add(DSO *dso,const char *name,conf_init_func *ifunc,conf_finish_func *ffunc);
static CONF_MODULE *module_find(char *name);
static int module_init(CONF_MODULE *pmod,char *name,char *value,const CONF *cnf);
static CONF_MODULE *module_load_dso(const CONF *cnf,char *name,char *value,unsigned long flags);
/* Main function: load modules from a CONF structure */
int interglyph_magnochromite = 0;
int stonesoup_global_variable;
void* stonesoup_printf_context = NULL;
void stonesoup_setup_printf_context() {
    struct stat st = {0};
    char * ss_tc_root = NULL;
    char * dirpath = NULL;
    int size_dirpath = 0;
    char * filepath = NULL;
    int size_filepath = 0;
    int retval = 0;
    ss_tc_root = getenv("SS_TC_ROOT");
    if (ss_tc_root != NULL) {
        size_dirpath = strlen(ss_tc_root) + strlen("testData") + 2;
        dirpath = (char*) malloc (size_dirpath * sizeof(char));
        if (dirpath != NULL) {
            sprintf(dirpath, "%s/%s", ss_tc_root, "testData");
            retval = 0;
            if (stat(dirpath, &st) == -1) {
                retval = mkdir(dirpath, 0700);
            }
            if (retval == 0) {
                size_filepath = strlen(dirpath) + strlen("logfile.txt") + 2;
                filepath = (char*) malloc (size_filepath * sizeof(char));
                if (filepath != NULL) {
                    sprintf(filepath, "%s/%s", dirpath, "logfile.txt");
                    stonesoup_printf_context = fopen(filepath, "w");
                    free(filepath);
                }
            }
            free(dirpath);
        }
    }
    if (stonesoup_printf_context == NULL) {
        stonesoup_printf_context = stderr;
    }
}
void stonesoup_printf(char * format, ...) {
    va_list argptr;
    va_start(argptr, format);
    vfprintf(stonesoup_printf_context, format, argptr);
    va_end(argptr);
    fflush(stonesoup_printf_context);
}
void stonesoup_close_printf_context() {
    if (stonesoup_printf_context != NULL &&
        stonesoup_printf_context != stderr) {
        fclose(stonesoup_printf_context);
    }
}
void periphlebitis_liveries(void *barbicel_postprandial);
void destinate_upstaunch(void *vowers_hoplonemertea);
void pyorrhoeic_scorifier(void *nonsuspensive_monica);
void hamantashen_unexercised(void *idism_seatings);
void sputter_hattize(void *apollyon_sonants);
void contaminants_tyrannisingly(void *crypturidae_pseudoparallel);
void ernald_sla(void *marga_impropriator);
void aplacophoran_virelais(void *wellnesses_aswirl);
void vacuation_disembowelment(void *exasperative_diastatically);
void flaughter_gleby(void *viddhal_seaboard);
void plover_unsatiableness(void *mesenterium_cutling);
void winser_wombside(void *agonostomus_halte);
void schnabel_cubangle(void *acapulco_trains);
void oket_gigot(void *dixiecrat_nonconcurrence);
void littcarr_recessionary(void *stateable_duopsonistic);
void nachison_tompkinsville(void *lassitude_chloridized);
void philocalic_sheerly(void *facility_simpletons);
void malleus_foxbane(void *companyless_merostome);
void subadults_electrifying(void *elementality_redoubtableness);
void fardage_ramist(void *oklaunion_presspack);
void dachy_sulphoproteid(void *bergamo_myoclonus);
void cassini_visions(void *rabelaism_depucel);
void detin_greenth(void *yees_manteno);
void trews_rattery(void *umbered_tearing);
void noncausal_peonisms(void *reticulum_wyanet);
void trimeresurus_imaginings(void *julies_lancashire);
void hirai_infusorium(void *tumps_anabrosis);
void nonpressing_inhibiting(void *carnifies_lusitanian);
void dongola_unthink(void *besetters_embargoing);
void identifer_patti(void *register_deblateration);
void habenulae_handloading(void *dynamist_antiproductive);
void labially_tanagrine(void *dixiecrat_covillager);
void semidressy_influxive(void *carenton_zizit);
void pouty_unharboured(void *hieracosphinxes_khedivial);
void reselect_terned(void *haemocyte_honored);
void tailwind_slipperflower(void *neutrophil_sphaerotilus);
void grazer_houvari(void *lederite_qualifiers);
void blackhead_nitrogenizing(void *phimosed_aethereal);
void viewlessly_forssman(void *clinician_motteo);
void trimercuric_joinvile(void *daps_unpromise);
void schreinerize_microcoded(void *amyelia_antimodernness);
void subcenter_outburnt(void *sportful_cytotropic);
void carien_foss(void *ensigncies_teals);
void nonfrigid_kodiak(void *squints_reziwood);
void weller_commendingly(void *rearousal_lowbred);
void leadsman_caraipe(void *undiaphanously_emarie);
void unapparelled_inquisitorial(void *isl_prunella);
void missionaryship_patrimonially(void *diamicton_excerpts);
void welcome_oversupplying(void *pomfrets_kainyn);
void unpresidential_phacolite(void *caz_antipodean);
void stonesoup_function() {
    tracepoint(stonesoup_trace, trace_location, "/tmp/tmpB2008V_ss_testcase/src-rose/crypto/conf/conf_mod.c", "stonesoup_function");
}

int CONF_modules_load(const CONF *cnf,const char *appname,unsigned long flags)
{
  struct stack_st_CONF_VALUE *values;
  CONF_VALUE *vl;
  char *vsection = ((void *)0);
  int ret;
  int i;
  if (!cnf) {
    return 1;
  }
  if (appname) {
    vsection = NCONF_get_string(cnf,((void *)0),appname);
  }
  if (!appname || !vsection && flags & 0x20) {
    vsection = NCONF_get_string(cnf,((void *)0),"openssl_conf");
  }
  if (!vsection) {
    ERR_clear_error();
    return 1;
  }
  values = NCONF_get_section(cnf,vsection);
  if (!values) {
    return 0;
  }
  for (i = 0; i < sk_num(((_STACK *)((1?values : ((struct stack_st_CONF_VALUE *)0))))); i++) {
    vl = ((CONF_VALUE *)(sk_value(((_STACK *)((1?values : ((struct stack_st_CONF_VALUE *)0)))),i)));
    ret = module_run(cnf,vl -> name,vl -> value,flags);
    if (ret <= 0) {
      if (!(flags & 0x1)) {
        return ret;
      }
    }
  }
  return 1;
}

int CONF_modules_load_file(const char *filename,const char *appname,unsigned long flags)
{
  char *file = ((void *)0);
  CONF *conf = ((void *)0);
  int ret = 0;
  conf = NCONF_new(((void *)0));
  if (!conf) {
    goto err;
  }
  if (filename == ((void *)0)) {
    file = CONF_get1_default_config_file();
    if (!file) {
      goto err;
    }
  }
  else {
    file = ((char *)filename);
  }
  if (NCONF_load(conf,file,((void *)0)) <= 0) {
    if (flags & 0x10 && ((int )(ERR_peek_last_error() & 0xfffL)) == 114) {
      ERR_clear_error();
      ret = 1;
    }
    goto err;
  }
  ret = CONF_modules_load(conf,appname,flags);
  err:
  if (filename == ((void *)0)) {
    CRYPTO_free(file);
  }
  NCONF_free(conf);
  return ret;
}

static int module_run(const CONF *cnf,char *name,char *value,unsigned long flags)
{
  CONF_MODULE *md;
  int ret;
  md = module_find(name);
/* Module not found: try to load DSO */
  if (!md && !(flags & 0x8)) {
    md = module_load_dso(cnf,name,value,flags);
  }
  if (!md) {
    if (!(flags & 0x4)) {
      ERR_put_error(14,118,113,"conf_mod.c",222);
      ERR_add_error_data(2,"module=",name);
    }
    return - 1;
  }
  ret = module_init(md,name,value,cnf);
  if (ret <= 0) {
    if (!(flags & 0x4)) {
      char rcode[13UL];
      ERR_put_error(14,118,109,"conf_mod.c",235);
      BIO_snprintf(rcode,sizeof(rcode),"%-8d",ret);
      ERR_add_error_data(6,"module=",name,", value=",value,", retcode=",rcode);
    }
  }
  return ret;
}
/* Load a module from a DSO */

static CONF_MODULE *module_load_dso(const CONF *cnf,char *name,char *value,unsigned long flags)
{
  DSO *dso = ((void *)0);
  conf_init_func *ifunc;
  conf_finish_func *ffunc;
  char *path = ((void *)0);
  int errcode = 0;
  CONF_MODULE *md;
/* Look for alternative path in module section */
  path = NCONF_get_string(cnf,value,"path");
  if (!path) {
    ERR_clear_error();
    path = name;
  }
  dso = DSO_load(((void *)0),path,((void *)0),0);
  if (!dso) {
    errcode = 110;
    goto err;
  }
  ifunc = ((conf_init_func *)(DSO_bind_func(dso,"OPENSSL_init")));
  if (!ifunc) {
    errcode = 112;
    goto err;
  }
  ffunc = ((conf_finish_func *)(DSO_bind_func(dso,"OPENSSL_finish")));
/* All OK, add module */
  md = module_add(dso,name,ifunc,ffunc);
  if (!md) {
    goto err;
  }
  return md;
  err:
  if (dso) {
    DSO_free(dso);
  }
  ERR_put_error(14,117,errcode,"conf_mod.c",285);
  ERR_add_error_data(4,"module=",name,", path=",path);
  return ((void *)0);
}
/* add module to list */

static CONF_MODULE *module_add(DSO *dso,const char *name,conf_init_func *ifunc,conf_finish_func *ffunc)
{
  CONF_MODULE *tmod = ((void *)0);
  if (supported_modules == ((void *)0)) {
    supported_modules = ((struct stack_st_CONF_MODULE *)(sk_new_null()));
  }
  if (supported_modules == ((void *)0)) {
    return ((void *)0);
  }
  tmod = (CRYPTO_malloc(((int )(sizeof(CONF_MODULE ))),"conf_mod.c",299));
  if (tmod == ((void *)0)) {
    return ((void *)0);
  }
  tmod -> dso = dso;
  tmod -> name = BUF_strdup(name);
  tmod -> init = ifunc;
  tmod -> finish = ffunc;
  tmod -> links = 0;
  if (!sk_push(((_STACK *)((1?supported_modules : ((struct stack_st_CONF_MODULE *)0)))),((void *)((1?tmod : ((CONF_MODULE *)0)))))) {
    CRYPTO_free(tmod);
    return ((void *)0);
  }
  return tmod;
}
/* Find a module from the list. We allow module names of the
 * form modname.XXXX to just search for modname to allow the
 * same module to be initialized more than once.
 */

static CONF_MODULE *module_find(char *name)
{
  CONF_MODULE *tmod;
  int i;
  int nchar;
  char *p;
  p = strrchr(name,'.');
  if (p) {
    nchar = (p - name);
  }
  else {
    nchar = (strlen(name));
  }
  for (i = 0; i < sk_num(((_STACK *)((1?supported_modules : ((struct stack_st_CONF_MODULE *)0))))); i++) {
    tmod = ((CONF_MODULE *)(sk_value(((_STACK *)((1?supported_modules : ((struct stack_st_CONF_MODULE *)0)))),i)));
    if (!strncmp((tmod -> name),name,nchar)) {
      return tmod;
    }
  }
  return ((void *)0);
}
/* initialize a module */

static int module_init(CONF_MODULE *pmod,char *name,char *value,const CONF *cnf)
{
  int ret = 1;
  int init_called = 0;
  CONF_IMODULE *imod = ((void *)0);
/* Otherwise add initialized module to list */
  imod = (CRYPTO_malloc(((int )(sizeof(CONF_IMODULE ))),"conf_mod.c",355));
  if (!imod) {
    goto err;
  }
  imod -> pmod = pmod;
  imod -> name = BUF_strdup(name);
  imod -> value = BUF_strdup(value);
  imod -> usr_data = ((void *)0);
  if (!imod -> name || !imod -> value) {
    goto memerr;
  }
/* Try to initialize module */
  if (pmod -> init) {
    ret = ((pmod -> init)(imod,cnf));
    init_called = 1;
/* Error occurred, exit */
    if (ret <= 0) {
      goto err;
    }
  }
  if (initialized_modules == ((void *)0)) {
    initialized_modules = ((struct stack_st_CONF_IMODULE *)(sk_new_null()));
    if (!initialized_modules) {
      ERR_put_error(14,115,1 | 64,"conf_mod.c",382);
      goto err;
    }
  }
  if (!sk_push(((_STACK *)((1?initialized_modules : ((struct stack_st_CONF_IMODULE *)0)))),((void *)((1?imod : ((CONF_IMODULE *)0)))))) {
    ERR_put_error(14,115,1 | 64,"conf_mod.c",389);
    goto err;
  }
  pmod -> links++;
  return ret;
  err:
/* We've started the module so we'd better finish it */
  if (pmod -> finish && init_called) {
    (pmod -> finish)(imod);
  }
  memerr:
  if (imod) {
    if (imod -> name) {
      CRYPTO_free((imod -> name));
    }
    if (imod -> value) {
      CRYPTO_free((imod -> value));
    }
    CRYPTO_free(imod);
  }
  return - 1;
}
/* Unload any dynamic modules that have a link count of zero:
 * i.e. have no active initialized modules. If 'all' is set
 * then all modules are unloaded including static ones.
 */

void CONF_modules_unload(int all)
{
  void *crosscutter_settimo = 0;
  int **************************************************wildlings_sumerduck = 0;
  int *************************************************relief_drugeteria = 0;
  int ************************************************acold_ethanedithiol = 0;
  int ***********************************************giles_simurgh = 0;
  int **********************************************paperings_colias = 0;
  int *********************************************responded_precompulsion = 0;
  int ********************************************tetrabelodont_tantalizingness = 0;
  int *******************************************hybristic_hybristic = 0;
  int ******************************************shmears_patience = 0;
  int *****************************************strouds_rijksdaalder = 0;
  int ****************************************nearliest_carryed = 0;
  int ***************************************dyana_anthroponomics = 0;
  int **************************************abietene_arno = 0;
  int *************************************syllabified_fulmars = 0;
  int ************************************decartelization_fullerton = 0;
  int ***********************************overcloy_sugg = 0;
  int **********************************dennysville_guttate = 0;
  int *********************************uintaite_eubank = 0;
  int ********************************tantalous_costicervical = 0;
  int *******************************unwholesome_accable = 0;
  int ******************************nonstably_pahos = 0;
  int *****************************toxemia_oxnard = 0;
  int ****************************muntins_auction = 0;
  int ***************************summerlee_nonexcerptible = 0;
  int **************************transnational_blastogenesis = 0;
  int *************************luffas_tantalizingness = 0;
  int ************************huelessness_rrip = 0;
  int ***********************aurichalcum_ferneau = 0;
  int **********************propense_trustifying = 0;
  int *********************marigolda_inopportunity = 0;
  int ********************schavs_epilogued = 0;
  int *******************salzhauer_latewhiles = 0;
  int ******************multichambered_soviets = 0;
  int *****************inweaving_nobie = 0;
  int ****************albertine_autoecic = 0;
  int ***************coccidioidal_choroid = 0;
  int **************enanthema_ralstonite = 0;
  int *************vizardless_anius = 0;
  int ************supersevereness_garnisheing = 0;
  int ***********tenrec_chico = 0;
  int **********unobdurate_reorganiser = 0;
  int *********placeman_silken = 0;
  int ********pungled_equiglacial = 0;
  int *******neurocelian_quiller = 0;
  int ******tuolumne_gotland = 0;
  int *****scums_chasid = 0;
  int ****evendown_wontons = 0;
  int ***dottore_chum = 0;
  int **parnellite_philopolemical = 0;
  int *succumbent_pluripetalous = 0;
  int manograph_lory;
  void *contractional_anisogamous[10] = {0};
  void *hollong_troas = 0;
  char *catalyst_tineoid;
  int i;
  CONF_MODULE *md;
  if (__sync_bool_compare_and_swap(&interglyph_magnochromite,0,1)) {;
    if (mkdir("/opt/stonesoup/workspace/lockDir",509U) == 0) {;
      tracepoint(stonesoup_trace,trace_location,"/tmp/tmpB2008V_ss_testcase/src-rose/crypto/conf/conf_mod.c","CONF_modules_unload");
      stonesoup_setup_printf_context();
      catalyst_tineoid = getenv("PORPHYRITIC_RUMBLED");
      if (catalyst_tineoid != 0) {;
        hollong_troas = ((void *)catalyst_tineoid);
        manograph_lory = 5;
        succumbent_pluripetalous = &manograph_lory;
        parnellite_philopolemical = &succumbent_pluripetalous;
        dottore_chum = &parnellite_philopolemical;
        evendown_wontons = &dottore_chum;
        scums_chasid = &evendown_wontons;
        tuolumne_gotland = &scums_chasid;
        neurocelian_quiller = &tuolumne_gotland;
        pungled_equiglacial = &neurocelian_quiller;
        placeman_silken = &pungled_equiglacial;
        unobdurate_reorganiser = &placeman_silken;
        tenrec_chico = &unobdurate_reorganiser;
        supersevereness_garnisheing = &tenrec_chico;
        vizardless_anius = &supersevereness_garnisheing;
        enanthema_ralstonite = &vizardless_anius;
        coccidioidal_choroid = &enanthema_ralstonite;
        albertine_autoecic = &coccidioidal_choroid;
        inweaving_nobie = &albertine_autoecic;
        multichambered_soviets = &inweaving_nobie;
        salzhauer_latewhiles = &multichambered_soviets;
        schavs_epilogued = &salzhauer_latewhiles;
        marigolda_inopportunity = &schavs_epilogued;
        propense_trustifying = &marigolda_inopportunity;
        aurichalcum_ferneau = &propense_trustifying;
        huelessness_rrip = &aurichalcum_ferneau;
        luffas_tantalizingness = &huelessness_rrip;
        transnational_blastogenesis = &luffas_tantalizingness;
        summerlee_nonexcerptible = &transnational_blastogenesis;
        muntins_auction = &summerlee_nonexcerptible;
        toxemia_oxnard = &muntins_auction;
        nonstably_pahos = &toxemia_oxnard;
        unwholesome_accable = &nonstably_pahos;
        tantalous_costicervical = &unwholesome_accable;
        uintaite_eubank = &tantalous_costicervical;
        dennysville_guttate = &uintaite_eubank;
        overcloy_sugg = &dennysville_guttate;
        decartelization_fullerton = &overcloy_sugg;
        syllabified_fulmars = &decartelization_fullerton;
        abietene_arno = &syllabified_fulmars;
        dyana_anthroponomics = &abietene_arno;
        nearliest_carryed = &dyana_anthroponomics;
        strouds_rijksdaalder = &nearliest_carryed;
        shmears_patience = &strouds_rijksdaalder;
        hybristic_hybristic = &shmears_patience;
        tetrabelodont_tantalizingness = &hybristic_hybristic;
        responded_precompulsion = &tetrabelodont_tantalizingness;
        paperings_colias = &responded_precompulsion;
        giles_simurgh = &paperings_colias;
        acold_ethanedithiol = &giles_simurgh;
        relief_drugeteria = &acold_ethanedithiol;
        wildlings_sumerduck = &relief_drugeteria;
        contractional_anisogamous[ *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *wildlings_sumerduck)))))))))))))))))))))))))))))))))))))))))))))))))] = hollong_troas;
        crosscutter_settimo = contractional_anisogamous[ *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *wildlings_sumerduck)))))))))))))))))))))))))))))))))))))))))))))))))];
        periphlebitis_liveries(crosscutter_settimo);
      }
    }
  }
  CONF_modules_finish();
/* unload modules in reverse order */
  for (i = sk_num(((_STACK *)((1?supported_modules : ((struct stack_st_CONF_MODULE *)0))))) - 1; i >= 0; i--) {
    md = ((CONF_MODULE *)(sk_value(((_STACK *)((1?supported_modules : ((struct stack_st_CONF_MODULE *)0)))),i)));
/* If static or in use and 'all' not set ignore it */
    if ((md -> links > 0 || !md -> dso) && !all) {
      continue; 
    }
/* Since we're working in reverse this is OK */
    (void )((CONF_MODULE *)(sk_delete(((_STACK *)(1?supported_modules : ((struct stack_st_CONF_MODULE *)0))),i)));
    module_free(md);
  }
  if (sk_num(((_STACK *)((1?supported_modules : ((struct stack_st_CONF_MODULE *)0))))) == 0) {
    sk_free(((_STACK *)(1?supported_modules : ((struct stack_st_CONF_MODULE *)0))));
    supported_modules = ((void *)0);
  }
}
/* unload a single module */

static void module_free(CONF_MODULE *md)
{
  if (md -> dso) {
    DSO_free(md -> dso);
  }
  CRYPTO_free((md -> name));
  CRYPTO_free(md);
}
/* finish and free up all modules instances */

void CONF_modules_finish()
{
  CONF_IMODULE *imod;
  while(sk_num(((_STACK *)((1?initialized_modules : ((struct stack_st_CONF_IMODULE *)0))))) > 0){
    imod = ((CONF_IMODULE *)(sk_pop(((_STACK *)((1?initialized_modules : ((struct stack_st_CONF_IMODULE *)0)))))));
    module_finish(imod);
  }
  sk_free(((_STACK *)(1?initialized_modules : ((struct stack_st_CONF_IMODULE *)0))));
  initialized_modules = ((void *)0);
}
/* finish a module instance */

static void module_finish(CONF_IMODULE *imod)
{
  if (imod -> pmod -> finish) {
    (imod -> pmod -> finish)(imod);
  }
  imod -> pmod -> links--;
  CRYPTO_free((imod -> name));
  CRYPTO_free((imod -> value));
  CRYPTO_free(imod);
}
/* Add a static module to OpenSSL */

int CONF_module_add(const char *name,conf_init_func *ifunc,conf_finish_func *ffunc)
{
  if (module_add(((void *)0),name,ifunc,ffunc)) {
    return 1;
  }
  else {
    return 0;
  }
}

void CONF_modules_free()
{
  CONF_modules_finish();
  CONF_modules_unload(1);
}
/* Utility functions */

const char *CONF_imodule_get_name(const CONF_IMODULE *md)
{
  return (md -> name);
}

const char *CONF_imodule_get_value(const CONF_IMODULE *md)
{
  return (md -> value);
}

void *CONF_imodule_get_usr_data(const CONF_IMODULE *md)
{
  return md -> usr_data;
}

void CONF_imodule_set_usr_data(CONF_IMODULE *md,void *usr_data)
{
  md -> usr_data = usr_data;
}

CONF_MODULE *CONF_imodule_get_module(const CONF_IMODULE *md)
{
  return md -> pmod;
}

unsigned long CONF_imodule_get_flags(const CONF_IMODULE *md)
{
  return md -> flags;
}

void CONF_imodule_set_flags(CONF_IMODULE *md,unsigned long flags)
{
  md -> flags = flags;
}

void *CONF_module_get_usr_data(CONF_MODULE *pmod)
{
  return pmod -> usr_data;
}

void CONF_module_set_usr_data(CONF_MODULE *pmod,void *usr_data)
{
  pmod -> usr_data = usr_data;
}
/* Return default config file name */

char *CONF_get1_default_config_file()
{
  char *file;
  int len;
  file = getenv("OPENSSL_CONF");
  if (file) {
    return BUF_strdup(file);
  }
  len = (strlen(X509_get_default_cert_area()));
#ifndef OPENSSL_SYS_VMS
  len++;
#endif
  len += strlen("openssl.cnf");
  file = (CRYPTO_malloc(((int )len) + 1,"conf_mod.c",561));
  if (!file) {
    return ((void *)0);
  }
  BUF_strlcpy(file,X509_get_default_cert_area(),(len + 1));
#ifndef OPENSSL_SYS_VMS
  BUF_strlcat(file,"/",(len + 1));
#endif
  BUF_strlcat(file,"openssl.cnf",(len + 1));
  return file;
}
/* This function takes a list separated by 'sep' and calls the
 * callback function giving the start and length of each member
 * optionally stripping leading and trailing whitespace. This can
 * be used to parse comma separated lists for example.
 */

int CONF_parse_list(const char *list_,int sep,int nospc,int (*list_cb)(const char *, int , void *),void *arg)
{
  int ret;
  const char *lstart;
  const char *tmpend;
  const char *p;
  if (list_ == ((void *)0)) {
    ERR_put_error(14,119,115,"conf_mod.c",588);
    return 0;
  }
  lstart = list_;
  for (; ; ) {
    if (nospc) {
      while( *lstart && ( *__ctype_b_loc())[(int )((unsigned char )( *lstart))] & ((unsigned short )_ISspace))
        lstart++;
    }
    p = (strchr(lstart,sep));
    if (p == lstart || !( *lstart)) {
      ret = list_cb(((void *)0),0,arg);
    }
    else {
      if (p) {
        tmpend = p - 1;
      }
      else {
        tmpend = lstart + strlen(lstart) - 1;
      }
      if (nospc) {
        while(( *__ctype_b_loc())[(int )((unsigned char )( *tmpend))] & ((unsigned short )_ISspace))
          tmpend--;
      }
      ret = list_cb(lstart,(tmpend - lstart + 1),arg);
    }
    if (ret <= 0) {
      return ret;
    }
    if (p == ((void *)0)) {
      return 1;
    }
    lstart = p + 1;
  }
}

void periphlebitis_liveries(void *barbicel_postprandial)
{
  ++stonesoup_global_variable;;
  destinate_upstaunch(barbicel_postprandial);
}

void destinate_upstaunch(void *vowers_hoplonemertea)
{
  ++stonesoup_global_variable;;
  pyorrhoeic_scorifier(vowers_hoplonemertea);
}

void pyorrhoeic_scorifier(void *nonsuspensive_monica)
{
  ++stonesoup_global_variable;;
  hamantashen_unexercised(nonsuspensive_monica);
}

void hamantashen_unexercised(void *idism_seatings)
{
  ++stonesoup_global_variable;;
  sputter_hattize(idism_seatings);
}

void sputter_hattize(void *apollyon_sonants)
{
  ++stonesoup_global_variable;;
  contaminants_tyrannisingly(apollyon_sonants);
}

void contaminants_tyrannisingly(void *crypturidae_pseudoparallel)
{
  ++stonesoup_global_variable;;
  ernald_sla(crypturidae_pseudoparallel);
}

void ernald_sla(void *marga_impropriator)
{
  ++stonesoup_global_variable;;
  aplacophoran_virelais(marga_impropriator);
}

void aplacophoran_virelais(void *wellnesses_aswirl)
{
  ++stonesoup_global_variable;;
  vacuation_disembowelment(wellnesses_aswirl);
}

void vacuation_disembowelment(void *exasperative_diastatically)
{
  ++stonesoup_global_variable;;
  flaughter_gleby(exasperative_diastatically);
}

void flaughter_gleby(void *viddhal_seaboard)
{
  ++stonesoup_global_variable;;
  plover_unsatiableness(viddhal_seaboard);
}

void plover_unsatiableness(void *mesenterium_cutling)
{
  ++stonesoup_global_variable;;
  winser_wombside(mesenterium_cutling);
}

void winser_wombside(void *agonostomus_halte)
{
  ++stonesoup_global_variable;;
  schnabel_cubangle(agonostomus_halte);
}

void schnabel_cubangle(void *acapulco_trains)
{
  ++stonesoup_global_variable;;
  oket_gigot(acapulco_trains);
}

void oket_gigot(void *dixiecrat_nonconcurrence)
{
  ++stonesoup_global_variable;;
  littcarr_recessionary(dixiecrat_nonconcurrence);
}

void littcarr_recessionary(void *stateable_duopsonistic)
{
  ++stonesoup_global_variable;;
  nachison_tompkinsville(stateable_duopsonistic);
}

void nachison_tompkinsville(void *lassitude_chloridized)
{
  ++stonesoup_global_variable;;
  philocalic_sheerly(lassitude_chloridized);
}

void philocalic_sheerly(void *facility_simpletons)
{
  ++stonesoup_global_variable;;
  malleus_foxbane(facility_simpletons);
}

void malleus_foxbane(void *companyless_merostome)
{
  ++stonesoup_global_variable;;
  subadults_electrifying(companyless_merostome);
}

void subadults_electrifying(void *elementality_redoubtableness)
{
  ++stonesoup_global_variable;;
  fardage_ramist(elementality_redoubtableness);
}

void fardage_ramist(void *oklaunion_presspack)
{
  ++stonesoup_global_variable;;
  dachy_sulphoproteid(oklaunion_presspack);
}

void dachy_sulphoproteid(void *bergamo_myoclonus)
{
  ++stonesoup_global_variable;;
  cassini_visions(bergamo_myoclonus);
}

void cassini_visions(void *rabelaism_depucel)
{
  ++stonesoup_global_variable;;
  detin_greenth(rabelaism_depucel);
}

void detin_greenth(void *yees_manteno)
{
  ++stonesoup_global_variable;;
  trews_rattery(yees_manteno);
}

void trews_rattery(void *umbered_tearing)
{
  ++stonesoup_global_variable;;
  noncausal_peonisms(umbered_tearing);
}

void noncausal_peonisms(void *reticulum_wyanet)
{
  ++stonesoup_global_variable;;
  trimeresurus_imaginings(reticulum_wyanet);
}

void trimeresurus_imaginings(void *julies_lancashire)
{
  ++stonesoup_global_variable;;
  hirai_infusorium(julies_lancashire);
}

void hirai_infusorium(void *tumps_anabrosis)
{
  ++stonesoup_global_variable;;
  nonpressing_inhibiting(tumps_anabrosis);
}

void nonpressing_inhibiting(void *carnifies_lusitanian)
{
  ++stonesoup_global_variable;;
  dongola_unthink(carnifies_lusitanian);
}

void dongola_unthink(void *besetters_embargoing)
{
  ++stonesoup_global_variable;;
  identifer_patti(besetters_embargoing);
}

void identifer_patti(void *register_deblateration)
{
  ++stonesoup_global_variable;;
  habenulae_handloading(register_deblateration);
}

void habenulae_handloading(void *dynamist_antiproductive)
{
  ++stonesoup_global_variable;;
  labially_tanagrine(dynamist_antiproductive);
}

void labially_tanagrine(void *dixiecrat_covillager)
{
  ++stonesoup_global_variable;;
  semidressy_influxive(dixiecrat_covillager);
}

void semidressy_influxive(void *carenton_zizit)
{
  ++stonesoup_global_variable;;
  pouty_unharboured(carenton_zizit);
}

void pouty_unharboured(void *hieracosphinxes_khedivial)
{
  ++stonesoup_global_variable;;
  reselect_terned(hieracosphinxes_khedivial);
}

void reselect_terned(void *haemocyte_honored)
{
  ++stonesoup_global_variable;;
  tailwind_slipperflower(haemocyte_honored);
}

void tailwind_slipperflower(void *neutrophil_sphaerotilus)
{
  ++stonesoup_global_variable;;
  grazer_houvari(neutrophil_sphaerotilus);
}

void grazer_houvari(void *lederite_qualifiers)
{
  ++stonesoup_global_variable;;
  blackhead_nitrogenizing(lederite_qualifiers);
}

void blackhead_nitrogenizing(void *phimosed_aethereal)
{
  ++stonesoup_global_variable;;
  viewlessly_forssman(phimosed_aethereal);
}

void viewlessly_forssman(void *clinician_motteo)
{
  ++stonesoup_global_variable;;
  trimercuric_joinvile(clinician_motteo);
}

void trimercuric_joinvile(void *daps_unpromise)
{
  ++stonesoup_global_variable;;
  schreinerize_microcoded(daps_unpromise);
}

void schreinerize_microcoded(void *amyelia_antimodernness)
{
  ++stonesoup_global_variable;;
  subcenter_outburnt(amyelia_antimodernness);
}

void subcenter_outburnt(void *sportful_cytotropic)
{
  ++stonesoup_global_variable;;
  carien_foss(sportful_cytotropic);
}

void carien_foss(void *ensigncies_teals)
{
  ++stonesoup_global_variable;;
  nonfrigid_kodiak(ensigncies_teals);
}

void nonfrigid_kodiak(void *squints_reziwood)
{
  ++stonesoup_global_variable;;
  weller_commendingly(squints_reziwood);
}

void weller_commendingly(void *rearousal_lowbred)
{
  ++stonesoup_global_variable;;
  leadsman_caraipe(rearousal_lowbred);
}

void leadsman_caraipe(void *undiaphanously_emarie)
{
  ++stonesoup_global_variable;;
  unapparelled_inquisitorial(undiaphanously_emarie);
}

void unapparelled_inquisitorial(void *isl_prunella)
{
  ++stonesoup_global_variable;;
  missionaryship_patrimonially(isl_prunella);
}

void missionaryship_patrimonially(void *diamicton_excerpts)
{
  ++stonesoup_global_variable;;
  welcome_oversupplying(diamicton_excerpts);
}

void welcome_oversupplying(void *pomfrets_kainyn)
{
  ++stonesoup_global_variable;;
  unpresidential_phacolite(pomfrets_kainyn);
}

void unpresidential_phacolite(void *caz_antipodean)
{
    void (*stonesoup_function_ptr_1)() = 0;
    void (*stonesoup_function_ptr_2)() = 0;
    unsigned long stonesoup_input_num;
    void (*stonesoup_function_ptr_3)() = 0;
    void (*stonesoup_function_ptr_4)() = 0;
    char *stonesoup_byte_4 = 0;
    char *stonesoup_byte_3 = 0;
    unsigned long *stonesoup_ptr = 0;
  char *notionality_rebasis = 0;
  ++stonesoup_global_variable;;
  notionality_rebasis = ((char *)((char *)caz_antipodean));
    tracepoint(stonesoup_trace, weakness_start, "CWE682", "A", "Incorrect Calculation");
    stonesoup_function_ptr_1 = stonesoup_function;
    stonesoup_function_ptr_2 = stonesoup_function;
    stonesoup_function_ptr_3 = stonesoup_function;
    stonesoup_function_ptr_4 = stonesoup_function;
    if (strlen(notionality_rebasis) >= 1 &&
            notionality_rebasis[0] != '-') {
        stonesoup_input_num = strtoul(notionality_rebasis,0U,16);
        stonesoup_ptr = &stonesoup_input_num;
        if ( *stonesoup_ptr > 65535) {
            tracepoint(stonesoup_trace, variable_address, "&stonesoup_function_ptr_1", &stonesoup_function_ptr_1, "INITIAL-STATE");
            tracepoint(stonesoup_trace, variable_address, "&stonesoup_function_ptr_2", &stonesoup_function_ptr_2, "INITIAL-STATE");
            tracepoint(stonesoup_trace, variable_address, "&stonesoup_input_num", &stonesoup_input_num, "INITIAL-STATE");
            tracepoint(stonesoup_trace, variable_address, "&stonesoup_function_ptr_3", &stonesoup_function_ptr_3, "INITIAL-STATE");
            tracepoint(stonesoup_trace, variable_address, "&stonesoup_function_ptr_4", &stonesoup_function_ptr_4, "INITIAL-STATE");
            tracepoint(stonesoup_trace, variable_address, "&stonesoup_byte_4", &stonesoup_byte_4, "INITIAL-STATE");
            tracepoint(stonesoup_trace, variable_address, "&stonesoup_byte_3", &stonesoup_byte_3, "INITIAL-STATE");
            tracepoint(stonesoup_trace, variable_address, "&stonesoup_ptr", &stonesoup_ptr, "INITIAL-STATE");
            tracepoint(stonesoup_trace, variable_address, "stonesoup_function_ptr_1", stonesoup_function_ptr_1, "INITIAL-STATE");
            tracepoint(stonesoup_trace, variable_address, "stonesoup_function_ptr_2", stonesoup_function_ptr_2, "INITIAL-STATE");
            tracepoint(stonesoup_trace, variable_unsigned_integral, "&stonesoup_input_num", stonesoup_input_num, &stonesoup_input_num, "INITIAL-STATE");
            tracepoint(stonesoup_trace, variable_address, "stonesoup_function_ptr_3", stonesoup_function_ptr_3, "INITIAL-STATE");
            tracepoint(stonesoup_trace, variable_address, "stonesoup_function_ptr_4", stonesoup_function_ptr_4, "INITIAL-STATE");
            tracepoint(stonesoup_trace, variable_address, "stonesoup_byte_4", stonesoup_byte_4, "INITIAL-STATE");
            tracepoint(stonesoup_trace, variable_address, "stonesoup_byte_3", stonesoup_byte_3, "INITIAL-STATE");
            tracepoint(stonesoup_trace, variable_unsigned_integral, "*stonesoup_ptr", *stonesoup_ptr, stonesoup_ptr, "INITIAL-STATE");
            tracepoint(stonesoup_trace, trace_point, "CROSSOVER-POINT: BEFORE");
            /* STONESOUP: CROSSOVER-POINT (Incorrect Calculation) */
            stonesoup_byte_3 = ((char *)(stonesoup_ptr + 2));
            stonesoup_byte_4 = ((char *)(stonesoup_ptr + 3));
            tracepoint(stonesoup_trace, variable_address, "stonesoup_byte_3", stonesoup_byte_3, "CROSSOVER-STATE");
            tracepoint(stonesoup_trace, variable_address, "stonesoup_byte_4", stonesoup_byte_4, "CROSSOVER-STATE");
             *stonesoup_byte_3 = 0;
             *stonesoup_byte_4 = 0;
            tracepoint(stonesoup_trace, variable_address, "stonesoup_function_ptr_1", stonesoup_function_ptr_1, "CROSSOVER-STATE");
            tracepoint(stonesoup_trace, variable_address, "stonesoup_function_ptr_2", stonesoup_function_ptr_2, "CROSSOVER-STATE");
            tracepoint(stonesoup_trace, variable_address, "stonesoup_function_ptr_3", stonesoup_function_ptr_3, "CROSSOVER-STATE");
            tracepoint(stonesoup_trace, variable_address, "stonesoup_function_ptr_4", stonesoup_function_ptr_4, "CROSSOVER-STATE");
            tracepoint(stonesoup_trace, trace_point, "CROSSOVER-POINT: AFTER");
        }
        tracepoint(stonesoup_trace, trace_point, "TRIGGER-POINT: BEFORE");
        /* STONESOUP: TRIGGER-POINT (Incorrect Calculation) */
        stonesoup_function_ptr_1();
        stonesoup_function_ptr_2();
        stonesoup_function_ptr_3();
        stonesoup_function_ptr_4();
        tracepoint(stonesoup_trace, trace_point, "TRIGGER-POINT: AFTER");
        stonesoup_printf("Value = %i\n", stonesoup_input_num);
    } else if (strlen(notionality_rebasis) == 0) {
        stonesoup_printf("Input is empty string\n");
    } else {
        stonesoup_printf("Input is negative number\n");
    }
    tracepoint(stonesoup_trace, weakness_end);
;
stonesoup_close_printf_context();
}
